bookmarks

package
v0.0.0-...-692cb10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DismissMsg

type DismissMsg struct{}

DismissMsg is sent when the user closes the bookmark list.

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the bookmark list overlay.

func New

func New(store *bookmark.Store, currentPath string, width, height int) Model

New creates a new bookmark list overlay.

func (Model) BoxSize

func (m Model) BoxSize(screenWidth, screenHeight int) (int, int)

BoxSize returns desired box dimensions.

func (Model) Update

func (m Model) Update(msg tea.KeyMsg) (Model, tea.Cmd)

Update handles key events.

func (Model) View

func (m Model) View(th theme.Theme, screenWidth, screenHeight int) string

View renders the bookmark list as a floating box.

type SelectMsg

type SelectMsg struct {
	Path string
}

SelectMsg is sent when the user selects a bookmark.

Jump to