cmdexec

package
v0.0.0-...-692cb10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CommandDoneMsg

type CommandDoneMsg struct {
	Output string
	Err    error
}

CommandDoneMsg delivers the result of an executed command.

type DismissMsg

type DismissMsg struct{}

DismissMsg is sent when the user closes the command overlay.

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the command execution overlay.

func New

func New(dir string, width, height int) Model

New creates a new command execution overlay for the given directory.

func (Model) BoxSize

func (m Model) BoxSize(screenWidth, screenHeight int) (int, int)

BoxSize returns the desired box dimensions for the overlay.

func (Model) Update

func (m Model) Update(msg tea.Msg) (Model, tea.Cmd)

Update handles messages.

func (Model) View

func (m Model) View(th theme.Theme, screenWidth, screenHeight int) string

View renders the command execution overlay.

Jump to