overlay

package
v0.0.0-...-692cb10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Place

func Place(bg string, boxContent string, bgWidth, bgHeight, boxWidth, boxHeight int) string

Place composites a box on top of a background string, centered. The background remains visible around the box.

func RenderBox

func RenderBox(title string, contentLines []string, footer string, width, height int, borderColor, bgColor, titleColor lipgloss.Color) string

RenderBox draws a bordered box with title, content lines, and optional footer.

Types

This section is empty.

Jump to