package
Version:
v0.0.0-...-692cb10
Opens a new window with list of versions in this module.
Published: Apr 20, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
DismissMsg is sent when the user closes the bookmark list.
Model is the bookmark list overlay.
New creates a new bookmark list overlay.
BoxSize returns desired box dimensions.
Update handles key events.
View renders the bookmark list as a floating box.
type SelectMsg struct {
Path string
}
SelectMsg is sent when the user selects a bookmark.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.