package
Version:
v0.0.0-...-692cb10
Opens a new window with list of versions in this module.
Published: Apr 20, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func Place(bg string, boxContent string, bgWidth, bgHeight, boxWidth, boxHeight int) string
-
func RenderBox(title string, contentLines []string, footer string, width, height int, ...) string
Place composites a box on top of a background string, centered.
The background remains visible around the box.
RenderBox draws a bordered box with title, content lines, and optional footer.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.